#!/bin/bash
#Uninstall

function init_vars() {
 PRODUCT=FlashphonerWebCallServer

 VERSION=`cat /usr/local/$PRODUCT/conf/WCS.version`
 FLASHPHONER_WCS_HOME=/usr/local/$PRODUCT
 FLASHPHONER_WCS_HOME_FULL=/usr/local/$PRODUCT-$VERSION
 INSTALL_LOG=$FLASHPHONER_WCS_HOME/bin/install.log
 
 MAIN_PID='FlashphonerMainWebCallServer.pid'
 PID_PATH='/var/run'

 FLASHPHONER_USER='flashphoner'

 DAEMON_TYPE=`ps --no-headers -o comm 1`
}

function show_confirmation(){
 echo "Are you sure you want to uninstall $PRODUCT?"
 echo "Enter 'yes' or press Ctrl+C to exit."
 read confirm < /dev/tty    
 if [ "$confirm" != "yes" ]; then
	show_confirmation
 fi
}

#deactivate license if exists
function check_and_deactivate(){
 if [ -f $FLASHPHONER_WCS_HOME/conf/flashphoner.license ]; then
	echo ""
	echo "Found active license, deactivating"
	echo ""
	$FLASHPHONER_WCS_HOME/bin/deactivation.sh
 fi
}

function remove_service {
 if [[ $DAEMON_TYPE == 'systemd' ]]; then
  systemctl disable webcallserver
  rm -rf /etc/systemd/system/webcallserver.service
  systemctl daemon-reload
 else 
  if [ -f /proc/version ]; then
    if grep -e "Red Hat\|centos" /proc/version > /dev/null; then
      chkconfig --del webcallserver
      rm -rf /etc/init.d/webcallserver
    elif grep -e "[Dd]ebian\|[Uu]buntu" /proc/version > /dev/null; then
      update-rc.d -f webcallserver remove
      rm -rf /etc/init.d/webcallserver
    fi    
  else 
    echo "Unable to determine your distribution name"
  fi
 fi  
}

function check_server_state {
 if [[ -f $FLASHPHONER_WCS_HOME/bin/setenv.sh && $(grep "WCS_NON_ROOT=true" $FLASHPHONER_WCS_HOME/bin/setenv.sh) ]]; then
  PID_PATH="$FLASHPHONER_WCS_HOME/bin"
 fi
 if [[ -f $PID_PATH/$MAIN_PID && $(pgrep -F $PID_PATH/$MAIN_PID) ]]; then
  echo -e "\nStopping $PRODUCT before uninstall\n"
  if [[ $DAEMON_TYPE == 'systemd' ]]; then
   systemctl stop webcallserver
  else 
   service webcallserver stop
  fi  
  if [[ -f $PID_PATH/$MAIN_PID && $(pgrep -F $PID_PATH/$MAIN_PID) ]]; then
   echo -e "Service did not stop, stopping application\n"
   $FLASHPHONER_WCS_HOME/bin/webcallserver stop
  fi
 fi
}

function remove_old_files() {
 if [ -f $INSTALL_LOG ]; then
  echo "Removing $PRODUCT files according to install.log..."
  cat $INSTALL_LOG | while read line; do
   if [ -f $line ]; then
	  rm -rf $line
   fi
  done
  echo "- Removing old files completed."
 fi
}

function remove_user() {
 if [[ $(getent passwd $FLASHPHONER_USER) =~ "$FLASHPHONER_USER" ]]; then
  userdel $FLASHPHONER_USER
 fi
}

function remove_product_folder() {
 cd /
 rm -f $FLASHPHONER_WCS_HOME
 rm -rf $FLASHPHONER_WCS_HOME_FULL 
}

function main() {
 echo "**************************************************"
 echo "*                                                *"
 echo "*             Uninstalling Flashphoner           *"
 echo "*                                                *"
 echo "* (c) Flashphoner.com 2013. All rights reserved  *"
 echo "*                                                *"
 echo "**************************************************"
 echo ""                                                                                                           

 init_vars
 show_confirmation
 check_server_state
 check_and_deactivate

 echo "UNINSTALLING Flashphoner..."
 echo ""

 remove_service
 remove_old_files
 remove_product_folder
 remove_user

 echo ""
 echo "***************************************************************************"
 echo "*                                                                         *"
 echo "*                         Uninstallation complete!                        *"
 echo "*                                                                         *"
 echo "*  Thank you for trying Flashphoner!                                      *"
 echo "*  Please restart server before further work                               *"
 echo "*  Support - support@flashphoner.com, forum - www.flashphoner.com/forums  *"
 echo "*  Press Enter to continue                                                *"
 echo "*                                                                         *"
 echo "***************************************************************************"
 echo ""

 read cont < /dev/tty
}

main "$@"

exit 0


